# Esercizio Magazzino

# DATI
param nG;
set G := 1..nG;
param k;			# Costo fisso per ogni operazione di scarico []
param h;			# Costo fisso di giacenza [/u]
param qmin;			# Ordine minimo [u]
param qmax;			# Ordine massimo [u]

# VARIABILI
var x {G} binary;		# Selezione di un giorno di rifornimento
var y {G} integer >=0;	# Giacenza durante ogni giorno [u]
var q {G} integer >=0;	# Quantit scaricata in ogni giorno [u]

# OBIETTIVO
minimize z : sum {g in G} (k * x[g] + h * y[g]);

# VINCOLI
# Limiti alla quantit ordinata in ogni rifornimento [u]
s.t. Ordine_minimo {g in G}: q[g] >= qmin * x[g];
s.t. Ordine_massimo {g in G}: q[g] <= qmax * x[g];

# Vincoli di conservazione del flusso [u]
s.t. Flusso_feriali {g in G: (g+1) mod 7 <> 0}: y[(g mod nG)+1] = y[g] + q[g] - 1;
s.t. Flusso_festivi {g in G: (g+1) mod 7  = 0}: y[(g mod nG)+1] = y[g] + q[g];

# I rifornimenti non possono avvenire di domenica
s.t. Domeniche {g in G: g mod 7 = 0}: x[g] = 0;

####################
data;
####################

param nG := 28;
param k := 400;
param h := 20;
param qmin := 5;
param qmax := 10;

end;
